## dbt-spark 1.10.0 - December 22, 2025

### Features

- add query timeout and retry handling for pyhive connections ([#1419](https://github.com/dbt-labs/dbt-adapters/issues/1419))
- add query timeout and retry handling for pyhive connections ([#1419](https://github.com/dbt-labs/dbt-adapters/issues/1419))
- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))

### Fixes

- update alter_relation_add_remove_columns to quote column names ([#63](https://github.com/dbt-labs/dbt-adapters/issues/63))
- update alter_relation_add_remove_columns to quote column names ([#63](https://github.com/dbt-labs/dbt-adapters/issues/63))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
- Cap logbook at less than 1.9 to avoid breaking change ([#N/A](https://github.com/dbt-labs/dbt-adapters/pull/N/A))
- Cap logbook at less than 1.9 to avoid breaking change ([#N/A](https://github.com/dbt-labs/dbt-adapters/pull/N/A))
